@@ -542,8 +542,10 @@ public class NonSequentialPDFParser extends PDFParser
         long prev = startXrefOffset;
         // ---- parse whole chain of xref tables/object streams using PREV
         // reference
-        while (prev > 0)
+        long lastPrev = -1;
+        while (prev > 0 && prev != lastPrev)
         {
+            lastPrev = prev;
             // seek to xref table
             setPdfSource(prev);
 
@@ -580,12 +582,27 @@ public class NonSequentialPDFParser extends PDFParser
                     fixedOffset = checkXRefOffset(streamOffset);
                     if (fixedOffset > -1 && fixedOffset != streamOffset)
                     {
+                        LOG.warn("/XRefStm offset " + streamOffset + " is incorrect, corrected to " + fixedOffset);
                         streamOffset = (int)fixedOffset;
                         trailer.setInt(COSName.XREF_STM, streamOffset);
                     }
                     setPdfSource(streamOffset);
                     skipSpaces();
-                    parseXrefObjStream(prev, false); 
+                    try
+                    {
+                        parseXrefObjStream(prev, false);
+                    }
+                    catch (IOException ex)
+                    {
+                        if (isLenient)
+                        {
+                            LOG.error("Failed to parse /XRefStm at offset " + streamOffset, ex);
+                        }
+                        else
+                        {
+                            throw ex;
+                        }
+                    }
                 }
                 prev = trailer.getInt(COSName.PREV);
                 if (prev > 0)
@@ -616,6 +633,11 @@ public class NonSequentialPDFParser extends PDFParser
                 }
             }
         }
+        if (prev == lastPrev)
+        {
+            //TODO better idea needed? PDFBOX-3446
+            throw new IOException("/Prev loop at offset " + prev);
+        }
         // ---- build valid xrefs out of the xref chain
         xrefTrailerResolver.setStartxref(startXrefOffset);
         COSDictionary trailer = xrefTrailerResolver.getTrailer();
